/*
 * Copyright FUOC.  All rights reserved.
 * @author Vicen Font Sagrist, 2012
 */
package edu.uoc.eAquarium.bussines;

import java.util.Collection;
import java.util.Iterator;

import javax.ejb.Stateless;
import javax.persistence.EntityManager;
import javax.persistence.PersistenceContext;
import javax.persistence.PersistenceException;

import edu.uoc.eAquarium.bussines.interfaces.CategoryFacadeRemote;
import edu.uoc.eAquarium.integration.Accessory.AccessoryJPA;
import edu.uoc.eAquarium.integration.Aquarium.AquariumJPA;
import edu.uoc.eAquarium.integration.ExoticFish.ExoticFishJPA;
import edu.uoc.eAquarium.integration.Order.OrderJPA;
import edu.uoc.eAquarium.integration.User.UserJPA;
import edu.uoc.eAquarium.integration.User.UserRegisteredJPA;

/**
 * EJB Session Bean Class of example "Practical Case Study JEE"
 */
@Stateless
public class CategoryFacade implements CategoryFacadeRemote {
	
	//Persistence Unit Context
	@PersistenceContext(unitName="PersistenceAquarium") 
	private EntityManager entman;

	  
	/**
	 * Method that  inserta en BD una nueva categora
	 */
	public void addCategoryAgenda(ExoticFishJPA categoryAgendaJPA) {

		
		entman.persist(categoryAgendaJPA);
	
	}
	
	/**
	 * Method that modifica una categora en concreto
	 */
	public void modifyCategoryAgenda(ExoticFishJPA categoryAgendaJPA) {

		entman.merge(categoryAgendaJPA);
			
	}
	
	/**
	 * Method that returns Collection of all categories
	 */
	public java.util.Collection<ExoticFishJPA> listAllCategoriesAgenda() {
		@SuppressWarnings("unchecked")
		Collection<ExoticFishJPA> allCategories = entman.createQuery("from ExoticFishJPA order by id").getResultList();
		return allCategories;
	}
	
	

	
	  
	
	/**
	 * Method that returns instance of the class ExoticFish
	 */
	public ExoticFishJPA showCategory(long categoryId)throws PersistenceException {
		ExoticFishJPA category = null;
		try
		{
 
			System.out.println("Entra en showCategory");
			Collection<ExoticFishJPA> categories = entman.createQuery("FROM ExoticFishJPA cat WHERE cat.id = ?1 ").setParameter(1, categoryId).getResultList();
			if (!categories.isEmpty() || categories.size()==1) {
				System.out.println("Entra para mostrar una categora");
				Iterator<ExoticFishJPA> iter =categories.iterator();
				category = (ExoticFishJPA) iter.next();				
			}
			
			System.out.println("Finaliza correctamente");
		}catch (PersistenceException e) {
			System.out.println(e);
		} catch (Exception e) {
			System.out.println(e);
		}
	    return category;
	}

	
	public void addAquarium(AquariumJPA aquariumJPA) {
		
		entman.persist(aquariumJPA);
		
	}

	
	public Collection<AquariumJPA> listAllAquariums() {
		@SuppressWarnings("unchecked")
		Collection<AquariumJPA> allAquariums = entman.createQuery("from AquariumJPA order by id").getResultList();
		return allAquariums;
	}

	
	public AquariumJPA showAquarium(long aquariumId)
			throws PersistenceException {
	
		AquariumJPA aquariumJPA = null;
		try
		{
 
			System.out.println("Entra en showAquarium");
			Collection<AquariumJPA> aquariums = entman.createQuery("FROM AquariumJPA cat WHERE cat.id = ?1 ").setParameter(1, aquariumId).getResultList();
			System.out.println("Entra en showAquarium2");
			if (!aquariums.isEmpty() || aquariums.size()==1) {
				System.out.println("Entra para mostrar una categora");
				Iterator<AquariumJPA> iter =aquariums.iterator();
				aquariumJPA = (AquariumJPA) iter.next();				
			}
			
			System.out.println("Finaliza correctamente");
		}catch (PersistenceException e) {
			System.out.println(e);
		} catch (Exception e) {
			System.out.println(e);
		}
	    return aquariumJPA;
	    
	}

	
	public void modifyAquarium(AquariumJPA aquariumJPA) {
		entman.merge(aquariumJPA);
		
	}

	
	public void addAccessory(AccessoryJPA accessoryJPA) {

		entman.persist(accessoryJPA);
		
	}

	
	public Collection<AccessoryJPA> listAllAccesories() {
		@SuppressWarnings("unchecked")
		Collection<AccessoryJPA> allAccesories = entman.createQuery("from AccessoryJPA order by id").getResultList();
		return allAccesories;
	}

	
	public AccessoryJPA showAccessory(long accessoryId)
			throws PersistenceException {
		AccessoryJPA accesory = null;
		try
		{
 
			System.out.println("Entra en showAccessory");
			Collection<AccessoryJPA> accessories = entman.createQuery("FROM AccessoryJPA cat WHERE cat.id = ?1 ").setParameter(1, accessoryId).getResultList();
			if (!accessories.isEmpty() || accessories.size()==1) {
				System.out.println("Entra para mostrar un accesorio");
				Iterator<AccessoryJPA> iter =accessories.iterator();
				accesory = (AccessoryJPA) iter.next();				
			}
			
			System.out.println("Finaliza correctamente");
		}catch (PersistenceException e) {
			System.out.println(e);
		} catch (Exception e) {
			System.out.println(e);
		}
	    return accesory;
	}

	
	public void modifyAccessory(AccessoryJPA accessoryJPA) {
		entman.merge(accessoryJPA);
		
	}

	
	public void addRegisteredUser(UserRegisteredJPA userAdministrationJPA) {
		entman.persist(userAdministrationJPA);
		
	}

	
	public UserJPA showUser(String login, String password)
			throws PersistenceException {
		UserJPA userJPA = null;
		try
		{
 
			System.out.println("Entra en show user");
			Collection<UserJPA> accessories = entman.createQuery("FROM UserJPA  WHERE login = ?1  and password = ?2")
					.setParameter(1, login).setParameter(2, password).getResultList();
			if (!accessories.isEmpty() || accessories.size()==1) {
				System.out.println("Entra para mostrar un accesorio");
				Iterator<UserJPA> iter =accessories.iterator();
				userJPA = (UserJPA) iter.next();				
			}
			
			System.out.println("Finaliza correctamente");
		}catch (PersistenceException e) {
			System.out.println(e);
		} catch (Exception e) {
			System.out.println(e);
		}
	    return userJPA;
	}

	@Override
	public void addUserIni(UserJPA userJPA) {
		entman.persist(userJPA);
	}

	@Override
	public UserJPA showUserByLogin(String login) throws PersistenceException {
		UserJPA userJPA = null;
		try
		{
 
			System.out.println("Entra en showUserByLogin");
			Collection<UserJPA> accessories = entman.createQuery("FROM UserJPA  WHERE login = ?1")
					.setParameter(1, login).getResultList();
			if (!accessories.isEmpty() || accessories.size()==1) {
				System.out.println("Entra para mostrar un usuario  filtrando por login");
				Iterator<UserJPA> iter =accessories.iterator();
				userJPA = (UserJPA) iter.next();				
			}
			
			System.out.println("Finaliza correctamente");
		}catch (PersistenceException e) {
			System.out.println(e);
		} catch (Exception e) {
			System.out.println(e);
		}
	    return userJPA;
	}


	public void removeAquarium(AquariumJPA aquariumJPA) {
		entman.remove(entman.merge(aquariumJPA));
		
	}


	public void removeExoticFish(ExoticFishJPA exoticFish) throws PersistenceException {
		entman.remove(entman.merge(exoticFish));
		
	}


	public void removeAccesory(AccessoryJPA accessoryJPA)
			throws PersistenceException {
		entman.remove(entman.merge(accessoryJPA));
		
	}

	@Override
	public void addOrderToUser(OrderJPA orderJPA)
			throws PersistenceException {
		entman.persist(orderJPA);
		
	}

	@Override
	public Collection<OrderJPA> listAllOrdersUser(String idUser)
			throws PersistenceException {
		Collection<OrderJPA> allOrderUSer = entman.createQuery("from OrderJPA ord  where "
				+ " ord.userJPA.login = ?1  order by id").setParameter(1, idUser).getResultList();
		
//		System.out.print("Order fish:"+ ((OrderJPA)allOrderUSer.iterator().next()).getExoticFishJPA().getName());
//		System.out.print("Order accesorio:"+ ((OrderJPA)allOrderUSer.iterator().next()).getAccessoryJPA());
		return allOrderUSer;
	}

	@Override
	public Collection<OrderJPA> listOrdersByProduct(long idProduct)
			throws PersistenceException {
		Collection<OrderJPA> allOrderUSer = entman.createQuery("from OrderJPA ord  where "
				+ " ord.exoticFishJPA.idFish = ?1  or "
				+ " ord.aquariumJPA.id = ?2  or "
				+ " ord.accessoryJPA.id = ?3  "
				+ " order by id").setParameter(1, idProduct).setParameter(2, idProduct).setParameter(3, idProduct).getResultList();

		return allOrderUSer;
	}	
}
