/*
 * Copyright FUOC.  All rights reserved.
 * @author Vicen Font Sagrist, 2012
 */
package edu.uoc.eAquarium.presentation.action.ListAccessories;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Iterator;
import java.util.Map;
import java.util.Properties;

import javax.ejb.EJB;
import javax.faces.bean.ManagedBean;
import javax.faces.bean.SessionScoped;
import javax.faces.context.FacesContext;
import javax.faces.event.ActionEvent;
import javax.faces.event.ValueChangeEvent;
import javax.naming.Context;
import javax.naming.InitialContext;

import edu.uoc.eAquarium.bussines.interfaces.CategoryFacadeRemote;
import edu.uoc.eAquarium.integration.Accessory.AccessoryJPA;
import edu.uoc.eAquarium.integration.Aquarium.AquariumJPA;



/**
 * Managed Bean ListCategoriesMBean
 */
@ManagedBean(name = "listAccessories")
@SessionScoped
public class ListAccessoriesMBean implements Serializable{
	
	private static final long serialVersionUID = 1L;	

	@EJB
	private CategoryFacadeRemote accesoryRemote;
	
	//stores the name of the category of listCategories to be displayed
	private String category = "ALL CATEGORIES";

	//stores the screen number where the user is 
	private int screen = 0;
	
	//stores ten or fewer CategoryAgendaJPA instances that the user can see on a screen
			protected Collection<AccessoryJPA> accesoryList;
			
	//stores ten or fewer CategoryAgendaJPA instances that the user can see on a screen
		protected Collection<AccessoryJPA> accesoryListView;
		
	//stores the total number of instances of AccessoryJPA
	protected int numberlistCategories = 0;

	/**
	 * Method that calculates the name of the category after analyzing where the user has
	 * clicked the mouse.
	 */
	public void categoryMap(ActionEvent e) {
		FacesContext context = FacesContext.getCurrentInstance();
		String categoryId = e.getComponent().getClientId(context);
		@SuppressWarnings("rawtypes")
		Map requestParams = context.getExternalContext().getRequestParameterMap();
		
		int x = new Integer((String) requestParams.get(categoryId + ".x")).intValue();
		int y = new Integer((String) requestParams.get(categoryId + ".y")).intValue();	
		
	
		this.setCategory(category);
	}


	
	/**
	 * Method that returns an instance Collection of 10 or less AccessoryJPA according screen 
	 * where the user is.
	 * @return Collection AccessoryJPA
	 * @throws Exception 
	 */
	public Collection<AccessoryJPA> getAccessoryListView() throws Exception {
	 
		accessoryList();
		 
		int n =0;
		accesoryListView = new ArrayList<AccessoryJPA>();
		for (Iterator<AccessoryJPA> iter2 = accesoryList.iterator(); iter2.hasNext();)
		{
			AccessoryJPA cat2 = (AccessoryJPA) iter2.next();
			if (n >= screen*10 && n< (screen*10+10))
			{				
				this.accesoryListView.add(cat2);
			}
			n +=1;
		}
		this.numberlistCategories = n;
		return accesoryListView;
	}
	
	/**
	 * Returns the total number of instances of AccessoryJPA
	 * @return AccessoryJPA number
	 */
	public int getNumberlistCategories()
	{ 
		return this.numberlistCategories;
	}
	
	/**
	 * allows forward or backward in user screens
	 */
	public void nextScreen()
	{
		if (((screen+1)*10 < accesoryList.size()))
		{
			screen +=1;
		}
	}
	public void previousScreen()
	{
		if ((screen > 0))
		{
			screen -=1;
		}
	}

	/**
	 * Get/set the Category name
	 * @return Category name
	 */
	public String getCategory()
	{
		return this.category;
	}
	
	public void setCategory(String category) {
		this.category = category;
	}
	
	public void categoryValueChanged(ValueChangeEvent categoryChanged) {
		this.category = categoryChanged.getNewValue().toString();
	}

	
	
	public String listAccessories() throws Exception { 
		accessoryList();
		return "AccessoryListView";
	}

	
	/**
	 * Method used for Facelet to call CategoryDetailView Facelet
	 * @return Facelet name
	 */
	public String setShowAccessory()
	{
		return "AccesoryDetailView";
	}
	
	
	/**
	 * Method that gets a list of instances by category or all AccessoryJPA
	 * @throws Exception
	 */
	@SuppressWarnings("unchecked")
	private void accessoryList() throws Exception
	{	
		Properties props = System.getProperties();
		Context ctx = new InitialContext(props);
		screen = 0;
		System.out.println("Recupera listado sin WS");
		accesoryRemote = (CategoryFacadeRemote) ctx.lookup("java:app/GestAquarium.jar/CategoryFacade!edu.uoc.eAquarium.bussines.interfaces.CategoryFacadeRemote");
		 
			accesoryList = (Collection<AccessoryJPA>)accesoryRemote.listAllAccesories();
		
		
	}

	
}
