/*
 * Copyright FUOC.  All rights reserved.
 * @author Vicen Font Sagrist, 2012
 */
package edu.uoc.eAquarium.presentation.action.ListCategories;

import java.io.ByteArrayInputStream;
import java.io.InputStream;
import java.io.Serializable;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Iterator;
import java.util.Map;
import java.util.Properties;

import javax.ejb.EJB;
import javax.faces.bean.ManagedBean;
import javax.faces.bean.SessionScoped;
import javax.faces.context.FacesContext;
import javax.faces.event.ActionEvent;
import javax.faces.event.ValueChangeEvent;
import javax.naming.Context;
import javax.naming.InitialContext;

import org.primefaces.model.DefaultStreamedContent;

import edu.uoc.eAquarium.bussines.interfaces.CategoryFacadeRemote;
import edu.uoc.eAquarium.integration.ExoticFish.ExoticFishJPA;


/**
 * Managed Bean ListCategoriesMBean
 */
@ManagedBean(name = "listCategories")
@SessionScoped
public class ListCategoriesMBean implements Serializable{
	
	private static final long serialVersionUID = 1L;	

	@EJB
	private CategoryFacadeRemote categoryRemote;
	
	private DefaultStreamedContent defaultStreamedContent;
	//stores the name of the category of listCategories to be displayed
	private String category = "ALL CATEGORIES";

	//stores the screen number where the user is 
	private int screen = 0;
	
	//stores ten or fewer CategoryAgendaJPA instances that the user can see on a screen
			protected Collection<ExoticFishJPA> categoriesList;
			
	//stores ten or fewer CategoryAgendaJPA instances that the user can see on a screen
		protected Collection<ExoticFishJPA> categoryListView;
		
	//stores the total number of instances of AquariumJPA
	protected int numberlistCategories = 0;

	/**
	 * Method that calculates the name of the category after analyzing where the user has
	 * clicked the mouse.
	 */
	public void categoryMap(ActionEvent e) {
		FacesContext context = FacesContext.getCurrentInstance();
		String categoryId = e.getComponent().getClientId(context);
		@SuppressWarnings("rawtypes")
		Map requestParams = context.getExternalContext().getRequestParameterMap();
		
		int x = new Integer((String) requestParams.get(categoryId + ".x")).intValue();
		int y = new Integer((String) requestParams.get(categoryId + ".y")).intValue();	
		
	
		this.setCategory(category);
	}


	
	/**
	 * @return the defaultStreamedContent
	 */
	public DefaultStreamedContent getDefaultStreamedContent() {
		return defaultStreamedContent;
	}



	/**
	 * @param defaultStreamedContent the defaultStreamedContent to set
	 */
	public void setDefaultStreamedContent(
			DefaultStreamedContent defaultStreamedContent) {
		this.defaultStreamedContent = defaultStreamedContent;
	}



	/**
	 * Method that returns an instance Collection of 10 or less ExoticFish according screen 
	 * where the user is.
	 * @return Collection ExoticFish
	 * @throws Exception 
	 */
	public Collection<ExoticFishJPA> getCategoryListView() throws Exception {
	 
		categoryList();
		 
		int n =0;
		categoryListView = new ArrayList<ExoticFishJPA>();
		for (Iterator<ExoticFishJPA> iter2 = categoriesList.iterator(); iter2.hasNext();)
		{
			ExoticFishJPA cat2 = (ExoticFishJPA) iter2.next();
			if (n >= screen*20 && n< (screen*20+20))
			{				
				this.categoryListView.add(cat2);
			}
			n +=1;
		}
		this.numberlistCategories = n;
		return categoryListView;
	}
	
	/**
	 * Returns the total number of instances of ExoticFish
	 * @return ExoticFish number
	 */
	public int getNumberlistCategories()
	{ 
		return this.numberlistCategories;
	}
	
	/**
	 * allows forward or backward in user screens
	 */
	public void nextScreen()
	{
		if (((screen+1)*10 < categoriesList.size()))
		{
			screen +=1;
		}
	}
	public void previousScreen()
	{
		if ((screen > 0))
		{
			screen -=1;
		}
	}

	/**
	 * Get/set the Category name
	 * @return Category name
	 */
	public String getCategory()
	{
		return this.category;
	}
	
	public void setCategory(String category) {
		this.category = category;
	}
	
	public void categoryValueChanged(ValueChangeEvent categoryChanged) {
		this.category = categoryChanged.getNewValue().toString();
	}

	
	
	public String listCategories() throws Exception { 
		categoryList();
		return "CategoryListView";
	}

	
	/**
	 * Method used for Facelet to call CategoryDetailView Facelet
	 * @return Facelet name
	 */
	public String setShowPet()
	{
		return "CategoryDetailView";
	}
	
	
	/**
	 * Method that gets a list of instances by category or all ExoticFish
	 * @throws Exception
	 */
	@SuppressWarnings("unchecked")
	private void categoryList() throws Exception
	{	
		Properties props = System.getProperties();
		Context ctx = new InitialContext(props);
		screen = 0;
		System.out.println("Recupera listado sin WS");
		categoryRemote = (CategoryFacadeRemote) ctx.lookup("java:app/GestAquarium.jar/CategoryFacade!edu.uoc.eAquarium.bussines.interfaces.CategoryFacadeRemote");
		 
			categoriesList = (Collection<ExoticFishJPA>)categoryRemote.listAllCategoriesAgenda();
		
		
	}

	
}
